ApplePayShippingMethod class abstract

Shipping method details regarding apple pay

Available extensions
Annotations
  • @freezed

Constructors

ApplePayShippingMethod({required String label, required String amount, required String identifier, bool? isPending, String? detail, int? startDate, int? endDate})
const
factory
ApplePayShippingMethod.fromJson(Map<String, dynamic> json)
factory

Properties

amount → String
The cost associated with this shipping option.
no setterinherited
copyWith → $ApplePayShippingMethodCopyWith<ApplePayShippingMethod>
Create a copy of ApplePayShippingMethod with the given fields replaced by the non-null parameter values.
no setterinherited
detail → String?
A user-readable description of the shipping method.
no setterinherited
endDate → int?
The unix timestamp of the end date of the expected range of delivery or shipping dates for a package, or the time range when an item is available for pickup.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
identifier → String
A unique identifier for the shipping method.
no setterinherited
isPending → bool?
When creating items for estimates or charges whose final value is not yet known, set this to true.
no setterinherited
label → String
A short, localized description.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDate → int?
The unix timestamp of the start date of the expected range of delivery or shipping dates for a package, or the time range when an item is available for pickup.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ApplePayShippingMethod value)) → TResult

Available on ApplePayShippingMethod, provided by the ApplePayShippingMethodPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ApplePayShippingMethod value)?) → TResult?

Available on ApplePayShippingMethod, provided by the ApplePayShippingMethodPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ApplePayShippingMethod value)?, {required TResult orElse()}) → TResult

Available on ApplePayShippingMethod, provided by the ApplePayShippingMethodPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String label, String amount, String identifier, bool? isPending, String? detail, int? startDate, int? endDate)?, {required TResult orElse()}) → TResult

Available on ApplePayShippingMethod, provided by the ApplePayShippingMethodPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ApplePayShippingMethod to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String label, String amount, String identifier, bool? isPending, String? detail, int? startDate, int? endDate)) → TResult

Available on ApplePayShippingMethod, provided by the ApplePayShippingMethodPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String label, String amount, String identifier, bool? isPending, String? detail, int? startDate, int? endDate)?) → TResult?

Available on ApplePayShippingMethod, provided by the ApplePayShippingMethodPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited