CardData class abstract

Card data associated with the token

Available extensions
Annotations
  • @freezed

Constructors

CardData({String? id, required String brand, String? country, String? currency, int? expYear, int? expMonth, String? name, String? funding, String? last4, Address? address})
const
factory
CardData.fromJson(Map<String, dynamic> json)
factory

Properties

address → Address?
Address of the cardholder
no setterinherited
brand → String
The brand associated to the card e.g. (visa, amex).
no setterinherited
copyWith → $CardDataCopyWith<CardData>
Create a copy of CardData with the given fields replaced by the non-null parameter values.
no setterinherited
country → String?
Two letter iso code.
no setterinherited
currency → String?
The three letter ISO 4217 code for the currency.
no setterinherited
expMonth → int?
two digit number representing the month of expire of the card.
no setterinherited
expYear → int?
four digit number representing the year of expiry of the card.
no setterinherited
funding → String?
card funding type e.g. (credit, debit).
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String?
Unique identifier
no setterinherited
last4 → String?
last four digits of the card.
no setterinherited
name → String?
Fullname of the cardholder
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_CardData value)) → TResult

Available on CardData, provided by the CardDataPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_CardData value)?) → TResult?

Available on CardData, provided by the CardDataPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_CardData value)?, {required TResult orElse()}) → TResult

Available on CardData, provided by the CardDataPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? id, String brand, String? country, String? currency, int? expYear, int? expMonth, String? name, String? funding, String? last4, Address? address)?, {required TResult orElse()}) → TResult

Available on CardData, provided by the CardDataPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this CardData to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? id, String brand, String? country, String? currency, int? expYear, int? expMonth, String? name, String? funding, String? last4, Address? address)) → TResult

Available on CardData, provided by the CardDataPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? id, String brand, String? country, String? currency, int? expYear, int? expMonth, String? name, String? funding, String? last4, Address? address)?) → TResult?

Available on CardData, provided by the CardDataPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited