CollectBankAccountTokenParams class abstract

Parameters that provide additional information for collecting the bankaccount for ACH payment

Available extensions
Annotations
  • @freezed

Constructors

CollectBankAccountTokenParams({UserInterfaceStyle? userInterfaceStyle, @JsonKey.new(includeFromJson: false, includeToJson: false) FinancialConnectionsEventHandler? onEvent, String? connectedAccountId})
const
factory
CollectBankAccountTokenParams.fromJson(Map<String, dynamic> json)
factory

Properties

connectedAccountId → String?
Optional connected account ID. Used for Stripe Connect embedded components.
no setterinherited
copyWith → $CollectBankAccountTokenParamsCopyWith<CollectBankAccountTokenParams>
Create a copy of CollectBankAccountTokenParams with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
onEvent → FinancialConnectionsEventHandler?
An optional event listener to receive FinancialConnectionsEvent for specific events during the process of a user connecting their financial accounts.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userInterfaceStyle → UserInterfaceStyle?
ios only. Style options for colors in Financial connections
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_CollectBankAccountTokenParams value)) → TResult

Available on CollectBankAccountTokenParams, provided by the CollectBankAccountTokenParamsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_CollectBankAccountTokenParams value)?) → TResult?

Available on CollectBankAccountTokenParams, provided by the CollectBankAccountTokenParamsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_CollectBankAccountTokenParams value)?, {required TResult orElse()}) → TResult

Available on CollectBankAccountTokenParams, provided by the CollectBankAccountTokenParamsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(UserInterfaceStyle? userInterfaceStyle, FinancialConnectionsEventHandler? onEvent, String? connectedAccountId)?, {required TResult orElse()}) → TResult

Available on CollectBankAccountTokenParams, provided by the CollectBankAccountTokenParamsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this CollectBankAccountTokenParams to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(UserInterfaceStyle? userInterfaceStyle, FinancialConnectionsEventHandler? onEvent, String? connectedAccountId)) → TResult

Available on CollectBankAccountTokenParams, provided by the CollectBankAccountTokenParamsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(UserInterfaceStyle? userInterfaceStyle, FinancialConnectionsEventHandler? onEvent, String? connectedAccountId)?) → TResult?

Available on CollectBankAccountTokenParams, provided by the CollectBankAccountTokenParamsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited