EmbeddedPaymentElementAppearance class abstract

Describes the appearance of the Embedded Mobile Payment Element

Available extensions
Annotations
  • @freezed

Properties

copyWith → $EmbeddedPaymentElementAppearanceCopyWith<EmbeddedPaymentElementAppearance>
Create a copy of EmbeddedPaymentElementAppearance with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
row RowConfig?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_EmbeddedPaymentElementAppearance value)) → TResult

Available on EmbeddedPaymentElementAppearance, provided by the EmbeddedPaymentElementAppearancePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_EmbeddedPaymentElementAppearance value)?) → TResult?

Available on EmbeddedPaymentElementAppearance, provided by the EmbeddedPaymentElementAppearancePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_EmbeddedPaymentElementAppearance value)?, {required TResult orElse()}) → TResult

Available on EmbeddedPaymentElementAppearance, provided by the EmbeddedPaymentElementAppearancePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(RowConfig? row)?, {required TResult orElse()}) → TResult

Available on EmbeddedPaymentElementAppearance, provided by the EmbeddedPaymentElementAppearancePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this EmbeddedPaymentElementAppearance to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(RowConfig? row)) → TResult

Available on EmbeddedPaymentElementAppearance, provided by the EmbeddedPaymentElementAppearancePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(RowConfig? row)?) → TResult?

Available on EmbeddedPaymentElementAppearance, provided by the EmbeddedPaymentElementAppearancePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited