GooglePayBillingAddressConfigPatterns extension

Adds pattern-matching-related methods to GooglePayBillingAddressConfig.

on

Methods

map<TResult extends Object?>(TResult $default(_GooglePayBillingAddressConfig value)) → TResult

Available on GooglePayBillingAddressConfig, provided by the GooglePayBillingAddressConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_GooglePayBillingAddressConfig value)?) → TResult?

Available on GooglePayBillingAddressConfig, provided by the GooglePayBillingAddressConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_GooglePayBillingAddressConfig value)?, {required TResult orElse()}) → TResult

Available on GooglePayBillingAddressConfig, provided by the GooglePayBillingAddressConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(bool? isRequired, bool? isPhoneNumberRequired, BillingAddressFormat? format)?, {required TResult orElse()}) → TResult

Available on GooglePayBillingAddressConfig, provided by the GooglePayBillingAddressConfigPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(bool? isRequired, bool? isPhoneNumberRequired, BillingAddressFormat? format)) → TResult

Available on GooglePayBillingAddressConfig, provided by the GooglePayBillingAddressConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(bool? isRequired, bool? isPhoneNumberRequired, BillingAddressFormat? format)?) → TResult?

Available on GooglePayBillingAddressConfig, provided by the GooglePayBillingAddressConfigPatterns extension

A variant of when that fallback to returning null