testEnv property

bool get testEnv
inherited

Whether or not to use the google pay test environment. Set to true until you have applied for and been granted access to the Production environment.

Implementation

String? get currencyCode;/// Whether or not to use the google pay test environment.  Set to `true` until you have applied for and been granted access to the Production environment.
bool get testEnv;