PaymentSheetPaymentOption class abstract

Available extensions
Annotations
  • @freezed

Constructors

PaymentSheetPaymentOption({required String label, String? image})
const
factory
PaymentSheetPaymentOption.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $PaymentSheetPaymentOptionCopyWith<PaymentSheetPaymentOption>
Create a copy of PaymentSheetPaymentOption with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
image String?
String decoding of the image
no setterinherited
label String
The label of the payment option
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_PaymentSheetPaymentOption value)) → TResult

Available on PaymentSheetPaymentOption, provided by the PaymentSheetPaymentOptionPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PaymentSheetPaymentOption value)?) → TResult?

Available on PaymentSheetPaymentOption, provided by the PaymentSheetPaymentOptionPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PaymentSheetPaymentOption value)?, {required TResult orElse()}) → TResult

Available on PaymentSheetPaymentOption, provided by the PaymentSheetPaymentOptionPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String label, String? image)?, {required TResult orElse()}) → TResult

Available on PaymentSheetPaymentOption, provided by the PaymentSheetPaymentOptionPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PaymentSheetPaymentOption to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String label, String? image)) → TResult

Available on PaymentSheetPaymentOption, provided by the PaymentSheetPaymentOptionPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String label, String? image)?) → TResult?

Available on PaymentSheetPaymentOption, provided by the PaymentSheetPaymentOptionPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited