PaymentSheetPresentOptions class abstract

Available extensions
Annotations
  • @freezed

Constructors

PaymentSheetPresentOptions({int? timeout})
const
factory
PaymentSheetPresentOptions.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $PaymentSheetPresentOptionsCopyWith<PaymentSheetPresentOptions>
Create a copy of PaymentSheetPresentOptions with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout int?
The number of milliseconds (after presenting) before the Payment Sheet closes automatically.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_PaymentSheetPresentOptions value)) → TResult

Available on PaymentSheetPresentOptions, provided by the PaymentSheetPresentOptionsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PaymentSheetPresentOptions value)?) → TResult?

Available on PaymentSheetPresentOptions, provided by the PaymentSheetPresentOptionsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PaymentSheetPresentOptions value)?, {required TResult orElse()}) → TResult

Available on PaymentSheetPresentOptions, provided by the PaymentSheetPresentOptionsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int? timeout)?, {required TResult orElse()}) → TResult

Available on PaymentSheetPresentOptions, provided by the PaymentSheetPresentOptionsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PaymentSheetPresentOptions to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int? timeout)) → TResult

Available on PaymentSheetPresentOptions, provided by the PaymentSheetPresentOptionsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int? timeout)?) → TResult?

Available on PaymentSheetPresentOptions, provided by the PaymentSheetPresentOptionsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited