PaymentSheetShapePatterns extension

Adds pattern-matching-related methods to PaymentSheetShape.

on

Methods

map<TResult extends Object?>(TResult $default(_PaymentSheetShape value)) → TResult

Available on PaymentSheetShape, provided by the PaymentSheetShapePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PaymentSheetShape value)?) → TResult?

Available on PaymentSheetShape, provided by the PaymentSheetShapePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PaymentSheetShape value)?, {required TResult orElse()}) → TResult

Available on PaymentSheetShape, provided by the PaymentSheetShapePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(double? borderRadius, double? borderWidth, PaymentSheetShadowParams? shadow)?, {required TResult orElse()}) → TResult

Available on PaymentSheetShape, provided by the PaymentSheetShapePatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(double? borderRadius, double? borderWidth, PaymentSheetShadowParams? shadow)) → TResult

Available on PaymentSheetShape, provided by the PaymentSheetShapePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(double? borderRadius, double? borderWidth, PaymentSheetShadowParams? shadow)?) → TResult?

Available on PaymentSheetShape, provided by the PaymentSheetShapePatterns extension

A variant of when that fallback to returning null