PlatformPayOrderDetails class abstract

Parameters related to order details with Apple pay

At this moment only Apple pay is supported. Similar to KPaymentOrderDetails See https://stripe.com/docs/apple-pay?platform=ios&locale=es-ES#order-tracking

Available extensions
Annotations
  • @freezed

Constructors

PlatformPayOrderDetails.applePay({required String orderTypeIdentifier, required String orderIdentifier, required String webServiceUrl, required String authenticationToken})
const
factory
PlatformPayOrderDetails.fromJson(Map<String, dynamic> json)
factory

Properties

authenticationToken String
eg: "abc123"
no setterinherited
copyWith → $PlatformPayOrderDetailsCopyWith<PlatformPayOrderDetails>
Create a copy of PlatformPayOrderDetails with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
orderIdentifier String
eg: "ABC123-AAAA-1111"
no setterinherited
orderTypeIdentifier String
eg: "com.myapp.order"
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webServiceUrl String
eg: "https://my-backend.example.com/apple-order-tracking-backend"
no setterinherited

Methods

map<TResult extends Object?>({required TResult applePay(_PlatformPayOrderDetails value)}) → TResult

Available on PlatformPayOrderDetails, provided by the PlatformPayOrderDetailsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? applePay(_PlatformPayOrderDetails value)?}) → TResult?

Available on PlatformPayOrderDetails, provided by the PlatformPayOrderDetailsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult applePay(_PlatformPayOrderDetails value)?, required TResult orElse()}) → TResult

Available on PlatformPayOrderDetails, provided by the PlatformPayOrderDetailsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult applePay(String orderTypeIdentifier, String orderIdentifier, String webServiceUrl, String authenticationToken)?, required TResult orElse()}) → TResult

Available on PlatformPayOrderDetails, provided by the PlatformPayOrderDetailsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PlatformPayOrderDetails to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult applePay(String orderTypeIdentifier, String orderIdentifier, String webServiceUrl, String authenticationToken)}) → TResult

Available on PlatformPayOrderDetails, provided by the PlatformPayOrderDetailsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? applePay(String orderTypeIdentifier, String orderIdentifier, String webServiceUrl, String authenticationToken)?}) → TResult?

Available on PlatformPayOrderDetails, provided by the PlatformPayOrderDetailsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited