PresentGooglePayParamsPatterns extension

Adds pattern-matching-related methods to PresentGooglePayParams.

on

Methods

map<TResult extends Object?>(TResult $default(_PresentGooglePayParams value)) → TResult

Available on PresentGooglePayParams, provided by the PresentGooglePayParamsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PresentGooglePayParams value)?) → TResult?

Available on PresentGooglePayParams, provided by the PresentGooglePayParamsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PresentGooglePayParams value)?, {required TResult orElse()}) → TResult

Available on PresentGooglePayParams, provided by the PresentGooglePayParamsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String clientSecret, bool forSetupIntent, String? currencyCode)?, {required TResult orElse()}) → TResult

Available on PresentGooglePayParams, provided by the PresentGooglePayParamsPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String clientSecret, bool forSetupIntent, String? currencyCode)) → TResult

Available on PresentGooglePayParams, provided by the PresentGooglePayParamsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String clientSecret, bool forSetupIntent, String? currencyCode)?) → TResult?

Available on PresentGooglePayParams, provided by the PresentGooglePayParamsPatterns extension

A variant of when that fallback to returning null