ShippingDetails class abstract

Shipping information

Available extensions
Annotations
  • @freezed

Constructors

ShippingDetails({required Address address, String? name, String? carrier, String? phone, String? trackingNumber})
const
factory
ShippingDetails.fromJson(Map<String, dynamic> json)
factory

Properties

address Address
Recipient address.
no setterinherited
carrier String?
Deliver service that will ship the product
no setterinherited
copyWith → $ShippingDetailsCopyWith<ShippingDetails>
Create a copy of ShippingDetails with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
name String?
Recipient name.
no setterinherited
phone String?
Recipient phone number.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trackingNumber String?
Tracking number of the shipment. If multiple tracking numbers separate them with commas.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ShippingDetails value)) → TResult

Available on ShippingDetails, provided by the ShippingDetailsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ShippingDetails value)?) → TResult?

Available on ShippingDetails, provided by the ShippingDetailsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ShippingDetails value)?, {required TResult orElse()}) → TResult

Available on ShippingDetails, provided by the ShippingDetailsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(Address address, String? name, String? carrier, String? phone, String? trackingNumber)?, {required TResult orElse()}) → TResult

Available on ShippingDetails, provided by the ShippingDetailsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ShippingDetails to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(Address address, String? name, String? carrier, String? phone, String? trackingNumber)) → TResult

Available on ShippingDetails, provided by the ShippingDetailsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(Address address, String? name, String? carrier, String? phone, String? trackingNumber)?) → TResult?

Available on ShippingDetails, provided by the ShippingDetailsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited