TokenData class abstract

Data that provides information about the token

Available extensions
Annotations
  • @freezed

Constructors

TokenData({required String id, @JsonKey.new(name: 'created') required String created, required TokenType type, required bool livemode, BankAccount? bankAccount, CardData? card})
const
factory
TokenData.fromJson(Map<String, dynamic> json)
factory

Properties

bankAccount BankAccount?
Bank account data
no setterinherited
card CardData?
Card data
no setterinherited
copyWith → $TokenDataCopyWith<TokenData>
Create a copy of TokenData with the given fields replaced by the non-null parameter values.
no setterinherited
created String
Timestamp when token was created
no setterinherited
createdDateTime String
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier of the token
no setterinherited
livemode bool
Whether or not the object exists in livemode
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type TokenType
Type of the token
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_TokenData value)) → TResult

Available on TokenData, provided by the TokenDataPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_TokenData value)?) → TResult?

Available on TokenData, provided by the TokenDataPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_TokenData value)?, {required TResult orElse()}) → TResult

Available on TokenData, provided by the TokenDataPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String id, String created, TokenType type, bool livemode, BankAccount? bankAccount, CardData? card)?, {required TResult orElse()}) → TResult

Available on TokenData, provided by the TokenDataPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this TokenData to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String id, String created, TokenType type, bool livemode, BankAccount? bankAccount, CardData? card)) → TResult

Available on TokenData, provided by the TokenDataPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String id, String created, TokenType type, bool livemode, BankAccount? bankAccount, CardData? card)?) → TResult?

Available on TokenData, provided by the TokenDataPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited