created property
Timestamp since epoch that represents the time the intent is created.
Implementation
num get amount;/// Timestamp since epoch that represents the time the intent is created.
String get created;
Timestamp since epoch that represents the time the intent is created.
num get amount;/// Timestamp since epoch that represents the time the intent is created.
String get created;