nextAction property
Additional action that needs to be taken in order to complete a payment using the provided resource.
Implementation
String? get canceledAt;/// Additional action that needs to be taken in order to complete a payment
/// using the provided resource.
NextAction? get nextAction;