allowsDelayedPaymentMethods property
Flag that allows payment methods that do not move money at the send of the checkout.
Defaul value is false.
Implementation
@JsonKey(name: 'link') LinkDisplayParams? get linkDisplayParams;/// Flag that allows payment methods that do not move money at the send of the checkout.
///
/// Defaul value is false.
bool get allowsDelayedPaymentMethods;